/*
 * Image codec. Author: Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 * This project is released under Creative Commons Zero (CC0) license.
 */
package eu.svjatoslav.imagesqueeze.codec;

/**
 * Class to hold image metadata.
 * Like image dimensions, header version, compression quality, etc..
 */

import eu.svjatoslav.commons.data.BitInputStream;
import eu.svjatoslav.commons.data.BitOutputStream;

import java.io.IOException;

public class ImageMetaData {

    int version;
    int width;
    int height;

    public void load(final BitInputStream inputStream) throws IOException {
        version = inputStream.readBits(16);
        width = ImageDecoder.readIntegerCompressed8(inputStream);
        height = ImageDecoder.readIntegerCompressed8(inputStream);
    }

    public void save(final BitOutputStream outputStream) throws IOException {
        outputStream.storeBits(version, 16);
        ImageEncoder.storeIntegerCompressed8(outputStream, width);
        ImageEncoder.storeIntegerCompressed8(outputStream, height);
    }

}
